@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 package TestSchema;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
-use parent 'DBIx::Class::Schema';
+use base 'DBIx::Class::Schema';
 
 __PACKAGE__->load_classes(qw(TestObject TestObjectExtra));
 
