@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 package TestSchema::TestObjectExtra;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
-use parent 'DBIx::Class';
+use base 'DBIx::Class';
 use Mixin::ExtraFields::Driver::DBIC -setup => { table => 'object_info' };
 
 __PACKAGE__->belongs_to(object => 'TestSchema::TestObject',
